==> magpie-data-0.5.11-sources.jar: io/openraven/magpie/data/aws/lambda/LambdaFunction.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.lambda;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.lambda.model.FunctionConfiguration;

import java.time.Instant;

@javax.persistence.Entity
@javax.persistence.Inheritance(strategy = javax.persistence.InheritanceType.TABLE_PER_CLASS)
@javax.persistence.Table(name = LambdaFunction.TABLE_NAME)
public class LambdaFunction extends AWSResource {

  protected static final String TABLE_NAME = "awslambdafunction";
  public static final String RESOURCE_TYPE = "AWS::Lambda::Function";

  @SuppressWarnings("unused")
  public LambdaFunction() {
    this.resourceType = RESOURCE_TYPE;
  }

  public LambdaFunction(String account, String regionId, FunctionConfiguration function) {
    this.awsRegion = regionId;
    this.awsAccountId = account;
    this.arn = function.functionArn();
    this.resourceId = function.revisionId();
    this.resourceName = function.functionName();
    this.configuration = PayloadUtils.update(function);
    this.resourceType = RESOURCE_TYPE;
    this.updatedIso = Instant.parse(function.lastModified());
  }

}

==> magpie-data-0.11.6-sources.jar: io/openraven/magpie/data/aws/lambda/LambdaFunction.java <==
/*-
 * #%L
 * Magpie API
 * %%
 * Copyright (C) 2021 Open Raven Inc
 * %%
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * #L%
 */
/*
 * Copyright 2021 Open Raven Inc
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.openraven.magpie.data.aws.lambda;

import io.openraven.magpie.data.aws.AWSResource;
import io.openraven.magpie.data.aws.shared.PayloadUtils;
import software.amazon.awssdk.services.lambda.model.FunctionConfiguration;

import java.time.Instant;

@jakarta.persistence.Entity
@jakarta.persistence.Inheritance(strategy = jakarta.persistence.InheritanceType.TABLE_PER_CLASS)
@jakarta.persistence.Table(name = LambdaFunction.TABLE_NAME)
public class LambdaFunction extends AWSResource {

  protected static final String TABLE_NAME = "awslambdafunction";
  public static final String RESOURCE_TYPE = "AWS::Lambda::Function";

  @SuppressWarnings("unused")
  public LambdaFunction() {
    this.resourceType = RESOURCE_TYPE;
  }

  public LambdaFunction(String account, String regionId, FunctionConfiguration function) {
    this.awsRegion = regionId;
    this.awsAccountId = account;
    this.arn = function.functionArn();
    this.resourceId = function.revisionId();
    this.resourceName = function.functionName();
    this.configuration = PayloadUtils.update(function);
    this.resourceType = RESOURCE_TYPE;
    this.updatedIso = Instant.parse(function.lastModified());
  }

}
